@@ -6,6 +6,10 @@
 
 #include "settingsmodel.h"
 
+#include <KWindowEffects>
+
+#include <QQuickWindow>
+
 SettingsModel* SettingsModel::instance()
 {
     static SettingsModel *s_settingsModel = new SettingsModel(qApp);
@@ -16,10 +20,6 @@ SettingsModel::SettingsModel(QObject *parent) :
     QObject(parent)
 {
     settings = new QSettings();
-    
-    setAudioCodec(audioCodec());
-    setContainerFormat(containerFormat());
-    setAudioQuality(audioQuality());
 }
 
 SettingsModel::~SettingsModel()
@@ -43,6 +43,10 @@ int SettingsModel::simpleAudioFormat() const
 
 void SettingsModel::setSimpleAudioFormat(int audioFormat)
 {
+    if (simpleAudioFormat() == audioFormat) {
+        return;
+    }
+    
     SimpleAudioFormat format = static_cast<SimpleAudioFormat>(audioFormat);
     setAudioCodec(formatMap[format].first);
     setContainerFormat(formatMap[format].second);
@@ -55,6 +59,10 @@ QString SettingsModel::audioCodec() const
 
 void SettingsModel::setAudioCodec(const QString &audioCodec)
 {
+    if (AudioRecorder::instance()->audioCodec() == audioCodec && this->audioCodec() == audioCodec) {
+        return;
+    }
+    
     AudioRecorder::instance()->setAudioCodec(audioCodec);
     settings->setValue(QStringLiteral("General/audioCodec"), audioCodec);
 
@@ -64,11 +72,16 @@ void SettingsModel::setAudioCodec(const QString &audioCodec)
 
 QString SettingsModel::containerFormat() const
 {
+    qDebug() << "format " << settings->value(QStringLiteral("General/containerFormat"), QStringLiteral("audio/ogg")).toString();
     return settings->value(QStringLiteral("General/containerFormat"), QStringLiteral("audio/ogg")).toString();
 }
 
 void SettingsModel::setContainerFormat(const QString &audioContainerFormat)
 {
+    if (AudioRecorder::instance()->containerFormat() == audioContainerFormat && containerFormat() != audioContainerFormat) {
+        return;
+    }
+    
     AudioRecorder::instance()->setContainerFormat(audioContainerFormat);
     settings->setValue(QStringLiteral("General/containerFormat"), audioContainerFormat);
     
@@ -83,6 +96,10 @@ int SettingsModel::audioQuality() const
 
 void SettingsModel::setAudioQuality(int audioQuality)
 {
+    if (this->audioQuality() == audioQuality) {
+        return;
+    }
+    
     QAudioEncoderSettings s = AudioRecorder::instance()->audioSettings();
     s.setQuality(static_cast<QMultimedia::EncodingQuality>(audioQuality));
     AudioRecorder::instance()->setAudioSettings(s);
@@ -91,3 +108,18 @@ void SettingsModel::setAudioQuality(int audioQuality)
     
     Q_EMIT audioQualityChanged();
 }
+
+void SettingsModel::setBlur(QQuickItem *item, bool blur)
+{
+    auto setWindows = [item, blur]() {
+        auto reg = QRect(QPoint(0, 0), item->window()->size());
+        KWindowEffects::enableBackgroundContrast(item->window(), blur, 1, 1, 1, reg);
+        KWindowEffects::enableBlurBehind(item->window(), blur, reg);
+    };
+
+    disconnect(item->window(), &QQuickWindow::heightChanged, this, nullptr);
+    disconnect(item->window(), &QQuickWindow::widthChanged, this, nullptr);
+    connect(item->window(), &QQuickWindow::heightChanged, this, setWindows);
+    connect(item->window(), &QQuickWindow::widthChanged, this, setWindows);
+    setWindows();
+}
